.. _traceability_goal:

====
Goal
====

Define documentation items which can be linked to each other. E.g. define requirements which can be derived from
other requirements, or linked to design items and test case descriptions.

Every item is an object in the documentation, which can have different relations to other objects in the documentation.
Documentation objects can be spread in different documents.

Two kinds of relationships exist:

- Internal relationships: Relationships between objects of the documentation (items). Once a (forward) relationship
  from item A to item B is defined, the reverse relationship from item B to item A is
  automatically generated by the plugin.

- External relationships: Relationship from an object of the documentation (item), to an external reference (url of
  e.g. an external tool). As no item B exists, the reverse relationship is also not defined.

Relationships are configurable.

The plugin can generate

- rendered versions of the defined documentation objects
- flat lists of documentation objects
- traceability matrices between objects
